starcluster.balancers.sge.visualizer

Package starcluster :: Package balancers :: Package sge :: Module visualizer |
[hide private]
[frames] | no frames]

# Module visualizer

source code

StarCluster SunGrinEngine stats visualizer module

Classes | [hide private]
| SGEVisualizer Stats Visualizer for SGE Load Balancer stats_file - file containing SGE load balancer stats pngpath - directory to dump the stat plots to

Variables | [hide private]
| __package__ = ``'``starcluster.balancers.sge``'``